import React from 'react'
import PropTypes from 'prop-types'
import moment from 'moment'
import { FilterItem } from 'components'
import { DownOutlined, UpOutlined } from '@ant-design/icons';
import { Form } from '@ant-design/compatible';
import '@ant-design/compatible/assets/index.css';
import {
  Button,
  Row,
  Col,
  Divider,
  Input,
  Select,
  DatePicker,
  TreeSelect,
  InputNumber,
  Cascader,
} from 'antd';

const FormItem = Form.Item;
const { RangePicker, MonthPicker } = DatePicker;
const SHOW_PARENT = TreeSelect.SHOW_PARENT;
const InputGroup = Input.Group;

const filterStyle = {
  style: {
    marginBottom: 16
  }
};

const formItemLayout = {
  labelCol: {
    span: 6
  },
  wrapperCol: {
    span: 18
  }
};
const Option = Select.Option;

const OrderFilterUnExpand = ({
  filterItems,
  onFilterChange,
  isExpand,
  form: {
    getFieldDecorator,
    getFieldsValue,
    setFieldsValue
  },
  expand,
  noExpand,
  noExpandButton
}) => {
  let filterItemsDealed = filterItems;

  const handleFields = (fields) => {
    for (let key in fields) {
      let field = fields[key];
      // 处理日期类型
      const keySel = filterItems.filter(val => {
        return val.id == key || val.id1 == key || val.id2 == key
      })
      if (keySel[0] && keySel[0].type == 'dateRule' && _.isArray(fields[key]) && fields[key].length > 0) {
        let timeStartValue = fields[key][0].valueOf();
        let timeEndValue = fields[key][1].valueOf();
        let timeStartKey = key + "Start";
        let timeEndKey = key + "End";
        fields[timeStartKey] = timeStartValue;
        fields[timeEndKey] = timeEndValue;
        delete fields[key];
      }
      // 删除请求中为空的对象
      if (keySel[0].type != 'numberBetween' && !field || (_.isString(field) && field.replace(/(^\s*)|(\s*$)/g, "").length == 0)
        || _.isUndefined(field)
        || _.isNull(field)
        || (_.isArray(field) && field.length === 0)) {
        delete fields[key];
        continue;
      }
    }
    return fields
  }

  const handleSubmit = () => {
    let fields = getFieldsValue()
    fields = handleFields(fields)
    onFilterChange(fields)
  }

  const handleReset = () => {
    const fields = getFieldsValue()
    for (let item in fields) {
      if ({}.hasOwnProperty.call(fields, item)) {
        if (fields[item] instanceof Array) {
          fields[item] = []
        } else {
          fields[item] = undefined
        }
      }
    }
    setFieldsValue(fields)
    handleSubmit()
  }

  const handleChange = (key, values) => {
    let fields = getFieldsValue()
    fields[key] = values
    fields = handleFields(fields)
    onFilterChange(fields)
  }

  const dateChange = (date, dateString) => {
    console.log(date, dateString);
  }
  const getFilterItemCol = (filterItems) => {
    const result = filterItems.map((filterItem, index) => <Col key={index} span={8} style={{ display: ((isExpand || index < 2) ? 'inline-block' : 'none') }}>
      <div id={`parent${index}`}>
        <FormItem label={filterItem.title} {...formItemLayout} style={{ minHeight: 40 }}>
          {filterItem.type == 'input' && getFieldDecorator(`${filterItem.id}`, { initialValue: filterItem.defaultValue })(<Input placeholder={filterItem.placeholder} onPressEnter={handleSubmit} />)}
          {filterItem.type == 'inputRange' && <InputGroup compact>
            {getFieldDecorator(`${filterItem.id}Start`, {})(<Input style={{ width: '40%', textAlign: 'center' }} placeholder={(filterItem.placeholder instanceof Array) ? filterItem.placeholder[0] : 'Minimum'} onPressEnter={handleSubmit} />)}
            <Input style={{ width: '20%', textAlign: 'center', pointerEvents: 'none', backgroundColor: '#fff' }} placeholder="~" disabled />
            {getFieldDecorator(`${filterItem.id}End`, {})(<Input style={{ width: '40%', textAlign: 'center' }} placeholder={(filterItem.placeholder instanceof Array) ? filterItem.placeholder[1] : 'Maximum'} onPressEnter={handleSubmit} />)}
          </InputGroup>}
          {filterItem.type === 'inputNumber' && getFieldDecorator(`${filterItem.id}`, { initialValue: filterItem.defaultValue })(<InputNumber
            placeholder={filterItem.placeholder} onPressEnter={handleSubmit} step={0.01} precision={2} {...filterItem} style={{ width: '100%' }} />)}
          {filterItem.type == 'select' && getFieldDecorator(`${filterItem.id}`, { initialValue: filterItem.defaultValue })(
            <Select
              initialValue={filterItem.defaultValue}
              allowClear={true}
              style={{
                width: '100%'
              }}
              showSearch={filterItem.showSearch}
              filterOption={(input, option) => option.props.children.toLowerCase().indexOf(input.toLowerCase()) >= 0}
              getPopupContainer={() => document.getElementById(`parent${index}`)}
            >
              {getOptions(filterItem.options)}
            </Select>
          )}
          {filterItem.type === 'treeSelect' && getFieldDecorator(`${filterItem.id}`, { initialValue: filterItem.defaultValue })(
            <TreeSelect
              initialValue={filterItem.defaultValue}
              treeData={filterItem.options}
              treeCheckable={filterItem.checkable ? filterItem.checkable : false}
              maxTagCount={filterItem.maxTagCount ? filterItem.maxTagCount : 1}
              showCheckedStrategy={SHOW_PARENT}
              searchPlaceholder={filterItem.searchPlaceholder}
              placeholder={filterItem.placeholder}
              style={{
                width: '100%'
              }}
              getPopupContainer={() => document.getElementById(`parent${index}`)}
            />
          )}
          {filterItem.type == 'dateRule' && getFieldDecorator(`${filterItem.id}`, {
            initialValue: filterItem?.bdTime ? [
              moment(filterItem.bdTime || '', filterItem.dateFormat || "YYYY/MM/DD"),
              moment(filterItem.edTime || '', filterItem.dateFormat || "YYYY/MM/DD")
            ] : ''
          })(<RangePicker
            style={{
              width: '100%'
            }}
            showTime
            format={filterItem.dateFormat || "YYYY/MM/DD"}
            onChange={dateChange} />)}
          {filterItem.type == 'date' && getFieldDecorator(`${filterItem.id}`, {})(<DatePicker
            style={{
              width: '100%'
            }}
            onChange={dateChange} />)}
          {filterItem.type == 'month' && getFieldDecorator(`${filterItem.id}`, { initialValue: filterItem.defaultValue })(<MonthPicker
            style={{
              width: '100%'
            }}
            onChange={dateChange} {...filterItem} />)}
          {filterItem.type === 'numberBetween' && (
            <InputGroup compact style={{
              width: '100%',
              display: 'flex'
            }}>
              {getFieldDecorator(`${filterItem.id1}`, { initialValue: filterItem.defaultValue1 })(
                <InputNumber style={{ width: '45%', textAlign: 'center' }} step={0.01} precision={2} min={0} placeholder={filterItem.placeholder1 ? filterItem.placeholder1 : ''} />
              )}
              <Input
                style={{
                  width: '10%',
                  borderRight: 0,
                  pointerEvents: 'none',
                  backgroundColor: '#fff',
                }}
                placeholder="~"
                disabled
              />
              {getFieldDecorator(`${filterItem.id2}`, { initialValue: filterItem.defaultValue2 })(
                <InputNumber style={{ width: '45%', textAlign: 'center' }} step={0.01} precision={2} min={0} placeholder={filterItem.placeholder2 ? filterItem.placeholder2 : ''} />
              )}
            </InputGroup>
          )}
          {filterItem.type == 'cascader' && getFieldDecorator(`${filterItem.id}`, {})(
            <Cascader style={{ width: '100%' }} options={filterItem.options} placeholder={filterItem.placeholder} />
          )}
        </FormItem>
      </div>
    </Col>);
    return ((result));
  }

  // 处理下拉选项
  const getOptions = (value) => value.map(option => {
    return <Option value={option.value} key={`${Math.random()}`}>{option.name}</Option>
  })

  const filterItemCols = getFilterItemCol(filterItemsDealed);
  console.info(noExpandButton)
  return (
    <Row gutter={24} {...filterStyle}>
      {filterItemCols}
      <Col span={8} style={{
        textAlign: 'left'
      }}>
        <Button type="primary" onClick={handleSubmit}>查询</Button>
        <Divider type="vertical" />
        <Button type="ghost" onClick={handleReset}>重置</Button>
        <Divider type="vertical" /> {_.isEmpty(noExpandButton) && !isExpand && <a
          style={{
            marginRight: 40
          }}
          onClick={expand}>
          展开 <DownOutlined />
        </a>}
        {_.isEmpty(noExpandButton) && isExpand && <a
          style={{
            marginRight: 40
          }}
          onClick={noExpand}>
          收起 <UpOutlined />
        </a>}
      </Col>
    </Row>
  );
}

OrderFilterUnExpand.propTypes = {
  form: PropTypes.object,
  filter: PropTypes.object,
  onFilterChange: PropTypes.func
}

export default Form.create({
  onFieldsChange(props, changedFields) {
    if (props.onChange) {
      props.onChange(changedFields);
    }
  }
})(OrderFilterUnExpand)