import React from 'react'
import PropTypes from 'prop-types'
import { BarsOutlined, MailOutlined, QuestionCircleOutlined, UserOutlined, SyncOutlined } from '@ant-design/icons'
import { Icon as LegacyIcon } from '@ant-design/compatible'
import { Menu, Popover } from 'antd'
import classnames from 'classnames'
import styles from './Header.less'
import Menus from './Menu'
import { Link } from 'umi'

const SubMenu = Menu.SubMenu

const Header = ({
  user,
  tenant,
  logout,
  switchSider,
  siderFold,
  isNavbar,
  menuPopoverVisible,
  location,
  switchMenuPopover,
  navOpenKeys,
  changeOpenKeys,
  menu,
  rightItemRender,
  kujialeInfo = {},
  onClickPerson
}) => {
  const menusProps = {
    menu,
    siderFold: false,
    darkTheme: false,
    isNavbar,
    handleClickNavMenu: switchMenuPopover,
    location,
    navOpenKeys,
    changeOpenKeys,
  }
  const handleClickPerson = () => {
    if (kujialeInfo.isBindingKjl === true || kujialeInfo.isBindingKjl === false) {
      onClickPerson()
    }
  }
  return (
    <div className={styles.header} style={{ left: isNavbar ? '0px' : siderFold ? '80px' : '200px' }}>
      {isNavbar ? (
        <Popover
          placement="bottomLeft"
          onVisibleChange={switchMenuPopover}
          visible={menuPopoverVisible}
          overlayClassName={styles.popovermenu}
          trigger="click"
          content={<Menus {...menusProps} />}
        >
          <div className={styles.button}>
            <BarsOutlined />
          </div>
        </Popover>
      ) : (
          <div className={styles.button} onClick={switchSider}>
            <LegacyIcon type={classnames({ 'menu-unfold': siderFold, 'menu-fold': !siderFold })} />
          </div>
        )}

      <div className={styles.rightWarpper}>
        {rightItemRender && rightItemRender()}
        {!rightItemRender && <a href="http://siteadmin.liweijia.com/" target="_blank" className={styles.site}>
          商品管理
        </a>}
        <Link className={styles.question} to={'/faq'}>
          常见问题
          <QuestionCircleOutlined />
        </Link>
        {
          <div
            className={styles.tenantName}
            style={{
              marginTop: 13,
            }}
          >
            {tenant.displayName}
          </div>
        }
        <div className={styles.button}>
          <MailOutlined />
        </div>
        <Menu mode="horizontal">
          <SubMenu
            style={{
              float: 'right',
            }}
            title={
              <span onClick={() => handleClickPerson()}>
                {user.name}{kujialeInfo.isBindingKjl === true ? <i className={styles.kujiale}></i> : (kujialeInfo.isBindingKjl === false ? <i className={styles.nokujiale}></i> : <SyncOutlined spin />)}
              </span>
            }
          >
            <Menu.Item key="person" disabled={!(kujialeInfo.isBindingKjl === true || kujialeInfo.isBindingKjl === false)} onClick={() => handleClickPerson()}>个人中心</Menu.Item>
            <Menu.Item key="logout" onClick={() => logout()}>注销</Menu.Item>
          </SubMenu>
        </Menu>
      </div>
    </div>
  )
}

Header.propTypes = {
  menu: PropTypes.array,
  user: PropTypes.object,
  logout: PropTypes.func,
  switchSider: PropTypes.func,
  siderFold: PropTypes.bool,
  isNavbar: PropTypes.bool,
  menuPopoverVisible: PropTypes.bool,
  location: PropTypes.object,
  switchMenuPopover: PropTypes.func,
  navOpenKeys: PropTypes.array,
  changeOpenKeys: PropTypes.func,
  rightItemRender: PropTypes.func,
}

export default Header
