import React from 'react'
import PropTypes from 'prop-types'
import { Icon as LegacyIcon } from '@ant-design/compatible';
import { Menu } from 'antd';
import { Link } from 'react-router-dom'
import { arrayToTree, queryArray } from 'utils'
import pathToRegexp from 'path-to-regexp'

const Menus = ({ siderFold, darkTheme, handleClickNavMenu, navOpenKeys, changeOpenKeys, menu, location }) => {
    // 生成树状
    const menuTree = arrayToTree(menu.filter(_ => _.pid !== '-1'), 'id', 'pid')
    const levelMap = {}

    const refreshThisPage=()=>{
        //  window.location.href=location.pathname
        return false;
    }

    // 递归生成菜单
    const getMenus = (menuTreeN, siderFoldN) => {
        return menuTreeN.map((item) => {
            if (item.children) {
                if (item.pid) {
                    levelMap[item.id] = item.pid
                }
                return (
                    <Menu.SubMenu
                key={item.id}
                title={<span>
                    {item.icon && <LegacyIcon type={item.icon} />}
                {(!siderFoldN || !menuTree.includes(item)) && item.name}
            </span>}
                >
                {getMenus(item.children, siderFoldN)}
            </Menu.SubMenu>
                );
            }
            return (
                <Menu.Item key={item.id}>
            {item.route===location.pathname && <div onClick={()=>{refreshThisPage()}}>
                {item.icon && <LegacyIcon type={item.icon} />}
                    {item.name}
                </div>}
                    {item.route!==location.pathname && <Link to={item.route || '#'}>
                        {item.icon && <LegacyIcon type={item.icon} />}
                            {item.name}
                        </Link>}
                        </Menu.Item>
            );
        });
    }
    const menuItems = getMenus(menuTree, siderFold)

    // 保持选中
    const getAncestorKeys = (key) => {
        let map = {}
        const getParent = (index) => {
            const result = [String(levelMap[index])]
            if (levelMap[result[0]]) {
                result.unshift(getParent(result[0])[0])
            }
            return result
        }
        for (let index in levelMap) {
            if ({}.hasOwnProperty.call(levelMap, index)) {
                map[index] = getParent(index)
            }
        }
        return map[key] || []
    }

    const onOpenChange = (openKeys) => {
        const latestOpenKey = openKeys.find(key => !navOpenKeys.includes(key))
        const latestCloseKey = navOpenKeys.find(key => !openKeys.includes(key))
        let nextOpenKeys = []
        if (latestOpenKey) {
            nextOpenKeys = getAncestorKeys(latestOpenKey).concat(latestOpenKey)
        }
        if (latestCloseKey) {
            nextOpenKeys = getAncestorKeys(latestCloseKey)
        }
        changeOpenKeys(nextOpenKeys)
    }

    let menuProps = !siderFold ? {
        onOpenChange,
        openKeys: navOpenKeys,
    } : {}


    // 寻找选中路由
    let currentMenu
    let defaultSelectedKeys
    for (let item of menu) {
        if (item.route && pathToRegexp(item.route).exec(location.pathname)) {
            currentMenu = item
            break
        }
    }
    const getPathArray = (array, current, pid, id) => {
        let result = [String(current[id])]
        const getPath = (item) => {
            if (item && item[pid]) {
                result.unshift(String(item[pid]))
                getPath(queryArray(array, item[pid], id))
            }
        }
        getPath(current)
        return result
    }
    if (currentMenu) {
        defaultSelectedKeys = getPathArray(menu, currentMenu, 'pid', 'id')
    }

    if (!defaultSelectedKeys) {
        defaultSelectedKeys = ['11']
    }

    return (
        <Menu
    {...menuProps}
    mode='inline'
    theme={darkTheme ? 'dark' : 'light'}
    onClick={handleClickNavMenu}
    selectedKeys={defaultSelectedKeys}
    inlineIndent="20"
        >
        {menuItems}
        </Menu>
)
}

Menus.propTypes = {
    menu: PropTypes.array,
    siderFold: PropTypes.bool,
    darkTheme: PropTypes.bool,
    handleClickNavMenu: PropTypes.func,
    navOpenKeys: PropTypes.array,
    changeOpenKeys: PropTypes.func,
    location: PropTypes.object,
}

export default Menus
