import React, { PureComponent, createElement } from 'react';
import PropTypes from 'prop-types';
import {Link} from 'umi';
import PageHeader from '../PageHeader';
import styles from './PageHeaderLayout.less';
import { config } from 'utils';
import pathToRegexp from 'path-to-regexp';

export default class PageHeaderLayout extends PureComponent {
  render() {

    const {children, wrapperClassName, top, ...restProps} = this.props;

    let _menu = config.menu,
        _breadcrumbList = [];

    function findParent(id){
      return _menu.find(val => val.id == id);
    }
    
    if(_menu){
      let _pathname = location.pathname,
          _item = _menu.find(val => val.route && pathToRegexp(val.route).exec(_pathname));

      if(_item){

        _breadcrumbList.push({
          ..._item,
          title: _item.name
        })

        while(_item.pid){
          let _pitem = findParent(_item.pid);
          if(_pitem){
            _item = _pitem;
            _breadcrumbList.unshift({
              ..._pitem,
              title: _pitem.name
            })
          }else{
            _item = {};
          }
        }
      }
    }

    const headerProps = {
      ...restProps,
      breadcrumbList: _breadcrumbList
    }
    return(<div style={{
      margin: '-24px -24px 0'
    }} className={wrapperClassName}>
      {top}
      <PageHeader key="pageheader" {...headerProps} linkElement={Link} key={_breadcrumbList}/> 
      {
        children
        ? <div className={styles.content}>{children}</div>
        : null
      }
    </div>)
  }
};
